@@ -12,6 +12,7 @@ from wagtail.core.utils import camelcase_to_underscore
 from modelcluster.fields import ParentalKey
 from wagtail.core.models import Orderable
 
+from webspace.bakery.models import VersionBuild
 from webspace.cms.amp.mixins import AmpMixin
 from webspace.cms.amp.utils import amp_mode_active
 from webspace.cms import constants
@@ -37,6 +38,10 @@ NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
 AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
 FormEntry = get_class('cms.blocks.entries', 'FormEntry')
 PortfoliosEntry = get_class('cms.blocks.entries', 'PortfoliosEntry')
+GalleryEntry = get_class('cms.blocks.entries', 'GalleryEntry')
+
+
+
 SocialShare = get_class('cms.blocks.static', 'SocialShare')
 SocialLinks = get_class('cms.blocks.static', 'SocialLinks')
 
@@ -132,7 +137,8 @@ class AGenericPage(Page):
         ('accordion', AccordionEntry()),
         ('numbers', NumbersEntry()),
         ('form', FormEntry()),
-        ('portfolios', PortfoliosEntry())
+        ('portfolios', PortfoliosEntry()),
+        ('gallery', GalleryEntry()),
     ], blank=True)
 
     content_panels = [
@@ -172,6 +178,7 @@ class AGenericPage(Page):
         context = super(AGenericPage, self).get_context(request)
         context['debug'] = settings.DEBUG
         context['icons'] = IconSnippet.get_context()
+        context['version'] = VersionBuild.get().version
         context['studio'] = {
             'name': constants.STUDIO_NAME,
             'email': constants.STUDIO_EMAIL,
